# tessellation

[![tests](https://github.com/ilikecubesnstuff/tessellation/actions/workflows/tests.yml/badge.svg)](https://github.com/ilikecubesnstuff/orbit-tessellation/actions/workflows/tests.yml)
[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://pdm.fming.dev)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)

A Python package for evaluating orbit commensurability using Delaunay tessellation. Use this in the [commensurability](https://github.com/ilikecubesnstuff/commensurability) package to analyze galaxy potentials.
